quantizationtools
=================

.. automodule:: abjad.tools.quantizationtools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.AttackPointOptimizer.AttackPointOptimizer
      ~abjad.tools.quantizationtools.GraceHandler.GraceHandler
      ~abjad.tools.quantizationtools.Heuristic.Heuristic
      ~abjad.tools.quantizationtools.JobHandler.JobHandler
      ~abjad.tools.quantizationtools.QEvent.QEvent
      ~abjad.tools.quantizationtools.QSchema.QSchema
      ~abjad.tools.quantizationtools.QSchemaItem.QSchemaItem
      ~abjad.tools.quantizationtools.QTarget.QTarget
      ~abjad.tools.quantizationtools.SearchTree.SearchTree

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.BeatwiseQSchema.BeatwiseQSchema
      ~abjad.tools.quantizationtools.BeatwiseQSchemaItem.BeatwiseQSchemaItem
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget
      ~abjad.tools.quantizationtools.CollapsingGraceHandler.CollapsingGraceHandler
      ~abjad.tools.quantizationtools.ConcatenatingGraceHandler.ConcatenatingGraceHandler
      ~abjad.tools.quantizationtools.DiscardingGraceHandler.DiscardingGraceHandler
      ~abjad.tools.quantizationtools.DistanceHeuristic.DistanceHeuristic
      ~abjad.tools.quantizationtools.MeasurewiseAttackPointOptimizer.MeasurewiseAttackPointOptimizer
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem
      ~abjad.tools.quantizationtools.MeasurewiseQTarget.MeasurewiseQTarget
      ~abjad.tools.quantizationtools.NaiveAttackPointOptimizer.NaiveAttackPointOptimizer
      ~abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer
      ~abjad.tools.quantizationtools.ParallelJobHandler.ParallelJobHandler
      ~abjad.tools.quantizationtools.ParallelJobHandlerWorker.ParallelJobHandlerWorker
      ~abjad.tools.quantizationtools.PitchedQEvent.PitchedQEvent
      ~abjad.tools.quantizationtools.QEventProxy.QEventProxy
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence
      ~abjad.tools.quantizationtools.QGrid.QGrid
      ~abjad.tools.quantizationtools.QGridContainer.QGridContainer
      ~abjad.tools.quantizationtools.QGridLeaf.QGridLeaf
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure
      ~abjad.tools.quantizationtools.QuantizationJob.QuantizationJob
      ~abjad.tools.quantizationtools.Quantizer.Quantizer
      ~abjad.tools.quantizationtools.SerialJobHandler.SerialJobHandler
      ~abjad.tools.quantizationtools.SilentQEvent.SilentQEvent
      ~abjad.tools.quantizationtools.TerminalQEvent.TerminalQEvent
      ~abjad.tools.quantizationtools.UnweightedSearchTree.UnweightedSearchTree
      ~abjad.tools.quantizationtools.WeightedSearchTree.WeightedSearchTree

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.quantizationtools.make_test_time_segments.make_test_time_segments
